# from directory.main-python-file import classname
from relevantpackage.relevantpackage import Relevantpackage

__author__ = 'E.Taskesen'
__email__ = 'erdogant@gmail.com'
__version__ = '0.1.2'

# module level doc-string
__doc__ = """
relevantpackage
================

Description
-----------
relevantpackage is a Python package used for demonstration purposes.
This information will show up when using the help function.

Example
-------
>>> # Import library
>>> from relevantpackage import Relevantpackage
>>> # Initialize
>>> model = Relevantpackage(message='Hello World')
>>> # Run the model
>>> model.show()

References
----------
* https://towardsdatascience.com/a-step-by-step-guide-in-detecting-causal-relationships-using-bayesian-structure-learning-in-python-c20c6b31cee5

"""